SystemOrganization addCategory: #ConfigurationOfSton!

Object subclass: #ConfigurationOfSton
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSton'!

!ConfigurationOfSton commentStamp: 'SvenVanCaekenberghe 2/19/2016 14:59' prior: 0!
I am ConfigurationOfSton, a Metacello configuration to load the STON (Smalltalk Object Notation) project.

	ConfigurationOfSton load.

Smalltalk Object Notation (STON) is a lightweight, text-based, human-readable data interchange format for class-based object-oriented languages like Smalltalk. It can be used to serialize domain level objects, either for persistency or network transport. As its name suggests, it is based on JSON (Javascript Object Notation). It adds symbols as a primitive value, class tags for object values and references.

See class STON which has an API on the class side and describes the syntax in its class comment.!

!ConfigurationOfSton class methodsFor: 'development support' stamp: 'SeanDeNigris 7/5/2012 19:06'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfSton class methodsFor: 'private' stamp: 'SeanDeNigris 7/5/2012 19:06'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfSton class methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 1/5/2016 09:33'!
catalogContactInfo
	^ 'Written and maintained by Sven Van Caekenberghe (http://stfx.eu) and the community. Discussions on the Pharo mailing lists.'! !

!ConfigurationOfSton class methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 1/5/2016 09:35'!
catalogDescription
	^ 'Smalltalk Object Notation (STON) is a lightweight, text-based, human-readable data interchange format for class-based object-oriented languages like Smalltalk. It can be used to serialize domain level objects, either for persistency or network transport. As its name suggests, it is based on JSON (Javascript Object Notation). It adds symbols as a primitive value, class tags for object values and references.'! !

!ConfigurationOfSton class methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 1/5/2016 09:36'!
catalogKeywords
	^ #(format input output serialization text encoding ston json)! !

!ConfigurationOfSton class methodsFor: 'private' stamp: 'SeanDeNigris 7/5/2012 19:06'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfSton class methodsFor: 'private' stamp: 'SeanDeNigris 7/5/2012 19:06'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfSton class methodsFor: 'metacello tool support' stamp: 'SeanDeNigris 7/5/2012 19:06'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSton class methodsFor: 'loading' stamp: 'SeanDeNigris 7/5/2012 19:06'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfSton class methodsFor: 'loading' stamp: 'SeanDeNigris 7/5/2012 19:06'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfSton class methodsFor: 'loading' stamp: 'SeanDeNigris 7/5/2012 19:06'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfSton class methodsFor: 'accessing' stamp: 'SeanDeNigris 7/5/2012 19:06'!
project

	^self new project! !

!ConfigurationOfSton class methodsFor: 'development support' stamp: 'SeanDeNigris 7/5/2012 19:06'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfSton methodsFor: 'baselines' stamp: 'SeanDeNigris 7/5/2012 19:11'!
baseline01: spec
	<version: '0.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://ss3.gemstone.com/ss/STON'.
		spec
			package: 'Ston-Core';
			package: 'Ston-Tests' ].
! !

!ConfigurationOfSton methodsFor: 'baselines' stamp: 'SvenVanCaekenberghe 10/26/2012 10:45'!
baseline02: spec
	<version: '0.2-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://ss3.gemstone.com/ss/STON'.
		spec
			package: 'STON-Core';
			package: 'STON-Tests' ].
! !

!ConfigurationOfSton methodsFor: 'baselines' stamp: 'SvenVanCaekenberghe 11/28/2013 19:20'!
baseline03: spec
	<version: '0.3-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://ss3.gemstone.com/ss/STON'.
		spec
			package: 'STON-Core';
			package: 'STON-Tests';
			group: 'Core' with: #('STON-Core') ].! !

!ConfigurationOfSton methodsFor: 'baselines' stamp: 'PavelKrivanek 6/1/2016 12:04'!
baseline04: spec
	<version: '0.4-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://ss3.gemstone.com/ss/STON'.
		spec
			package: 'STON-Core';
			package: 'STON-Tests';
			package: 'STON-Text support';
			group: 'Core' with: #('STON-Core');
			group: 'default' with: #('STON-Core' 'STON-Text support' 'STON-Tests') ].
		! !

!ConfigurationOfSton methodsFor: 'accessing' stamp: 'SeanDeNigris 7/5/2012 19:06'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSton methodsFor: 'symbolic versions' stamp: 'PavelKrivanek 6/1/2016 12:05'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '0.20'! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'SeanDeNigris 7/5/2012 19:12'!
version01: spec
	<version: '0.1' imports: #('0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: ''.
		spec author: 'SeanDeNigris'.
		spec timestamp: '7/5/2012 19:06'.
		spec
			package: 'Ston-Core' with: 'Ston-Core-SvenVanCaekenberghe.35';
			package: 'Ston-Tests' with: 'Ston-Tests-SvenVanCaekenberghe.33'. ].
! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 10/25/2012 17:41'!
version02: spec
	<version: '0.2' imports: #('0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec
			package: 'Ston-Core' with: 'Ston-Core-SvenVanCaekenberghe.36';
			package: 'Ston-Tests' with: 'Ston-Tests-SvenVanCaekenberghe.34'. ].
! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 10/26/2012 10:54'!
version03: spec
	<version: '0.3' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec
			package: 'STON-Core' with: 'STON-Core-SvenVanCaekenberghe.37';
			package: 'STON-Tests' with: 'STON-Tests-SvenVanCaekenberghe.29'. ]! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 12/18/2012 10:29'!
version04: spec
	<version: '0.4' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec
			package: 'STON-Core' with: 'STON-Core-SvenVanCaekenberghe.42';
			package: 'STON-Tests' with: 'STON-Tests-SvenVanCaekenberghe.39'. ]! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 3/7/2013 10:55'!
version05: spec
	<version: '0.5' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'release';
			package: 'STON-Core' with: 'STON-Core-SvenVanCaekenberghe.43';
			package: 'STON-Tests' with: 'STON-Tests-SvenVanCaekenberghe.40' ]! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 11/28/2013 19:21'!
version06: spec
	<version: '0.6' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'release';
			package: 'STON-Core' with: 'STON-Core-SvenVanCaekenberghe.45';
			package: 'STON-Tests' with: 'STON-Tests-SvenVanCaekenberghe.42' ]! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'DamienCassou 12/11/2013 16:46'!
version07: spec
	<version: '0.7' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'release';
			package: 'STON-Core' with: 'STON-Core-DamienCassou.46';
			package: 'STON-Tests' with: 'STON-Tests-SvenVanCaekenberghe.42' ]! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 1/21/2014 20:00'!
version08: spec
	<version: '0.8' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'release';
			package: 'STON-Core' with: 'STON-Core-SvenVanCaekenberghe.47';
			package: 'STON-Tests' with: 'STON-Tests-SvenVanCaekenberghe.42' ]! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 4/24/2014 13:38'!
version09: spec
	<version: '0.9' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'release';
			package: 'STON-Core' with: 'STON-Core-SvenVanCaekenberghe.49';
			package: 'STON-Tests' with: 'STON-Tests-SvenVanCaekenberghe.44' ]! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 12/8/2014 23:38'!
version10: spec
	<version: '0.10' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'release';
			package: 'STON-Core' with: 'STON-Core-SvenVanCaekenberghe.54';
			package: 'STON-Tests' with: 'STON-Tests-SvenVanCaekenberghe.48' ]! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 4/10/2015 15:33'!
version11: spec
	<version: '0.11' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'release';
			package: 'STON-Core' with: 'STON-Core-SvenVanCaekenberghe.55';
			package: 'STON-Tests' with: 'STON-Tests-SvenVanCaekenberghe.49' ]! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 4/10/2015 20:31'!
version12: spec
	<version: '0.12' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'release';
			package: 'STON-Core' with: 'STON-Core-SvenVanCaekenberghe.55';
			package: 'STON-Tests' with: 'STON-Tests-SvenVanCaekenberghe.50' ]! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 4/30/2015 20:31'!
version13: spec
	<version: '0.13' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'release';
			package: 'STON-Core' with: 'STON-Core-SvenVanCaekenberghe.57';
			package: 'STON-Tests' with: 'STON-Tests-SvenVanCaekenberghe.52' ]! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 5/28/2015 15:58'!
version14: spec
	<version: '0.14' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'release';
			package: 'STON-Core' with: 'STON-Core-SvenVanCaekenberghe.58';
			package: 'STON-Tests' with: 'STON-Tests-SvenVanCaekenberghe.53' ]! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 9/9/2015 13:53'!
version15: spec
	<version: '0.15' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'release';
			package: 'STON-Core' with: 'STON-Core-SvenVanCaekenberghe.63';
			package: 'STON-Tests' with: 'STON-Tests-SvenVanCaekenberghe.58' ]! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 2/19/2016 14:57'!
version16: spec
	<version: '0.16' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'release';
			package: 'STON-Core' with: 'STON-Core-SvenVanCaekenberghe.66';
			package: 'STON-Tests' with: 'STON-Tests-SvenVanCaekenberghe.59' ]! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 2/22/2016 12:35'!
version17: spec
	<version: '0.17' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'release';
			package: 'STON-Core' with: 'STON-Core-SvenVanCaekenberghe.67';
			package: 'STON-Tests' with: 'STON-Tests-SvenVanCaekenberghe.59' ]! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 4/17/2016 10:59'!
version18: spec
	<version: '0.18' imports: #('0.3-baseline')>

	spec for: #'common' do: [
		spec 
			blessing: #'release';
			package: 'STON-Core' with: 'STON-Core-SvenVanCaekenberghe.72';
			package: 'STON-Tests' with: 'STON-Tests-SvenVanCaekenberghe.64' ]! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'PavelKrivanek 4/20/2016 12:39'!
version19: spec
	<version: '0.19' imports: #('0.3-baseline')>

	spec for: #'common' do: [
		spec 
			blessing: #'release';
			package: 'STON-Core' with: 'STON-Core-PavelKrivanek.73';
			package: 'STON-Tests' with: 'STON-Tests-SvenVanCaekenberghe.64' ]! !

!ConfigurationOfSton methodsFor: 'versions' stamp: 'PavelKrivanek 6/1/2016 13:17'!
version20: spec
	<version: '0.20' imports: #('0.4-baseline')>

	spec for: #'common' do: [
		spec 
			blessing: #'release';
			package: 'STON-Core' with: 'STON-Core-PavelKrivanek.74';
			package: 'STON-Text support' with: 'STON-Text support-PavelKrivanek.1';
			package: 'STON-Tests' with: 'STON-Tests-SvenVanCaekenberghe.64' ]! !
